@@ -21,7 +21,7 @@ use Video::Pattern;
 Readonly::Scalar our $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Constructor.
 sub new {
@@ -39,6 +39,9 @@ sub new {
 	# Frames per second.
 	$self->{'fps'} = 60;
 
+	# FFmpeg video codec.
+	$self->{'ffmpeg_video_codec'} = undef;
+
 	# Image generator.
 	$self->{'image_generator'} = undef;
 
@@ -112,13 +115,17 @@ sub create {
 	my $images_path = catfile($self->{'temp_dir'},
 		'%03d.'.$self->{'image_type'});
 	my @command_options = ('-loglevel', 'error', '-r', $self->{'fps'},
-		'-i', $images_path, $out_path);
+		'-i', $images_path,
+		$self->{'ffmpeg_video_codec'}
+			? ('-c:v', $self->{'ffmpeg_video_codec'})
+			: (),
+		$out_path);
 	$ffmpeg->options(@command_options);
 	$ffmpeg->exec;
 	if ($ffmpeg->stderr) {
 		my @stderr = split m/\n/ms, $ffmpeg->stderr;
 		my $command = join $SPACE, @command_options;
-		err "Error with command '$command'.",
+		err "Error with command 'ffmpeg $command'.",
 			map { ('STDERR', $_) } @stderr;
 	}
 	if ($self->{'verbose'}) {
@@ -180,8 +187,13 @@ Video::Generator - Perl class for video generation.
  - h for hour.
  Default value is 10000 (10s).
 
+=item * C<ffmpeg_video_codec>
+
+ FFmpeg video codec.
+ Default value is undef, use default ffmpeg.
+
 =item * C<fps>
- 
+
  Frames per second.
  Default value is 60.
 
@@ -346,7 +358,15 @@ Perl class for creating random image.
 
 =item L<Image::Select>
 
-Perl class for creating random image.
+Selecting image from images directory.
+
+=item L<Image::Select::Array>
+
+Selecting image from list with checking.
+
+=item L<Image::Select::Date>
+
+Selecting image from images directory by date.
 
 =item L<Video::Delay>
 
@@ -375,6 +395,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
